import os
import socket
import threading

from . import rpc_pb2
from . import exceptions

__all__ = ['Connection']


################################################################################
def _VarintEncoder():
    """Return an encoder for a basic varint value (does not include tag)."""

    local_chr = chr

    def EncodeVarint(write, value):
        bits = value & 0x7f
        value >>= 7
        while value:
            write(local_chr(0x80 | bits))
            bits = value & 0x7f
            value >>= 7
        return write(local_chr(bits))

    return EncodeVarint

_EncodeVarint = _VarintEncoder()


def _VarintDecoder(mask):
    """Return an encoder for a basic varint value (does not include tag).

    Decoded values will be bitwise-anded with the given mask before being
    returned, e.g. to limit them to 32 bits.  The returned decoder does not
    take the usual "end" parameter -- the caller is expected to do bounds checking
    after the fact (often the caller can defer such checking until later).  The
    decoder returns a (value, new_pos) pair.
    """

    local_ord = ord

    def DecodeVarint(buffer, pos):
        result = 0
        shift = 0
        while 1:
            b = local_ord(buffer[pos])
            result |= ((b & 0x7f) << shift)
            pos += 1
            if not (b & 0x80):
                result &= mask
                return (result, pos)
            shift += 7
            if shift >= 64:
                raise IOError('Too many bytes when decoding varint.')
    return DecodeVarint

_DecodeVarint = _VarintDecoder((1 << 64) - 1)
_DecodeVarint32 = _VarintDecoder((1 << 32) - 1)

################################################################################


class _RPC(object):
    def __init__(self, socket_path, timeout, socket_constructor, lock_constructor):
        self.lock = lock_constructor()
        self.socket_path = socket_path
        self.timeout = timeout
        self.socket_timeout = timeout
        self.socket_constructor = socket_constructor
        self.sock = None

    def connect(self):
        self.sock = self.socket_constructor(socket.AF_UNIX, socket.SOCK_STREAM)
        self.sock.settimeout(self.socket_timeout)
        try:
            self.sock.connect(self.socket_path)
        except socket.error as e:
            self.sock = None
            raise exceptions.SocketError("Cannot connect to {}: {}".format(self.socket_path, e))

    def disconnect(self):
        if self.sock is not None:
            self.sock.close()
        self.sock = None

    def _sendall(self, data, flags=0):
        try:
            return self.sock.sendall(data, flags)
        except socket.timeout:
            raise exceptions.SocketTimeout("Got timeout: {}".format(self.socket_timeout))
        except socket.error as e:
            self.sock = None
            raise exceptions.SocketError("Send error: {}".format(e))

    def _recv(self, count, flags=0):
        try:
            buf = []
            l = 0
            while l < count:
                piece = self.sock.recv(count - l, flags)
                if len(piece) == 0:  # this means that socket is in invalid state
                    raise socket.error(socket.errno.ECONNRESET, os.strerror(socket.errno.ECONNRESET))
                buf.append(piece)
                l += len(piece)
            return ''.join(buf)
        except socket.timeout:
            raise exceptions.SocketTimeout("Got timeout: {}".format(self.socket_timeout))
        except socket.error as e:
            self.sock = None
            raise exceptions.SocketError("Recv error: {}".format(e))

    def call(self, request, timeout):
        data = request.SerializeToString()
        hdr = bytearray()
        _EncodeVarint(hdr.append, len(data))

        with self.lock:
            if timeout != self.socket_timeout:
                if self.sock is not None:
                    self.sock.settimeout(timeout)
                self.socket_timeout = timeout

            if self.sock is None:
                self.connect()

            try:
                try:
                    self._sendall(hdr)
                except exceptions.SocketError:
                    self.connect()
                    self._sendall(hdr)

                self._sendall(data)

                msb = 1
                buf = ""
                while msb:
                    b = self._recv(1)
                    msb = ord(b) >> 7
                    buf += b

                length = _DecodeVarint32(buf, 0)
                resp = rpc_pb2.TContainerResponse()
                buf += self._recv(length[0])
            finally:
                if self.socket_timeout != self.timeout:
                    if self.sock is not None:
                        self.sock.settimeout(self.timeout)
                    self.socket_timeout = self.timeout

        resp.ParseFromString(buf[length[1]:])

        if resp.error != rpc_pb2.Success:
            raise exceptions.EError.Create(resp.error, resp.errorMsg)

        return resp

    def List(self):
        request = rpc_pb2.TContainerRequest()
        request.list.CopyFrom(rpc_pb2.TContainerListRequest())
        return self.call(request, self.timeout).list.name

    def Create(self, name):
        request = rpc_pb2.TContainerRequest()
        request.create.name = name
        self.call(request, self.timeout)

    def CreateWeak(self, name):
        request = rpc_pb2.TContainerRequest()
        request.createWeak.name = name
        self.call(request, self.timeout)

    def Destroy(self, name):
        request = rpc_pb2.TContainerRequest()
        request.destroy.name = name
        self.call(request, self.timeout)

    def Start(self, name):
        request = rpc_pb2.TContainerRequest()
        request.start.name = name
        self.call(request, self.timeout)

    def Stop(self, name):
        request = rpc_pb2.TContainerRequest()
        request.stop.name = name
        self.call(request, self.timeout)

    def Kill(self, name, sig):
        request = rpc_pb2.TContainerRequest()
        request.kill.name = name
        request.kill.sig = sig
        self.call(request, self.timeout)

    def Pause(self, name):
        request = rpc_pb2.TContainerRequest()
        request.pause.name = name
        self.call(request, self.timeout)

    def Resume(self, name):
        request = rpc_pb2.TContainerRequest()
        request.resume.name = name
        self.call(request, self.timeout)

    def GetProperty(self, name, property):
        request = rpc_pb2.TContainerRequest()
        request.getProperty.name = name
        request.getProperty.property = property
        res = self.call(request, self.timeout).getProperty.value
        if res == 'false':
            return False
        elif res == 'true':
            return True
        return res

    def SetProperty(self, name, property, value):
        if value is False:
            value = 'false'
        elif value is True:
            value = 'true'
        elif value is None:
            value = ''
        elif isinstance(value, (int, long)):
            value = str(value)

        request = rpc_pb2.TContainerRequest()
        request.setProperty.name = name
        request.setProperty.property = property
        request.setProperty.value = value
        self.call(request, self.timeout)

    def GetData(self, name, data):
        request = rpc_pb2.TContainerRequest()
        request.getData.name = name
        request.getData.data = data
        res = self.call(request, self.timeout).getData.value
        if res == 'false':
            return False
        elif res == 'true':
            return True
        return res

    def Get(self, containers, variables):
        request = rpc_pb2.TContainerRequest()
        request.get.name.extend(containers)
        request.get.variable.extend(variables)
        resp = self.call(request, self.timeout)
        if resp.error != rpc_pb2.Success:
            raise exceptions.EError.Create(resp.error, resp.errorMsg)

        res = {}
        for container in resp.get.list:
            var = {}
            for kv in container.keyval:
                if kv.HasField('error'):
                    var[kv.variable] = exceptions.EError.Create(kv.error, kv.errorMsg)
                    continue
                if kv.value == 'false':
                    var[kv.variable] = False
                elif kv.value == 'true':
                    var[kv.variable] = True
                else:
                    var[kv.variable] = kv.value

            res[container.name] = var

        return res

    def ConvertPath(self, path, source, destination):
        request = rpc_pb2.TConvertPathRequest()
        request.convertPath.path = path
        request.convertPath.source = source
        request.convertPath.destination = destination
        res = self.call(request, self.timeout).convertPath.path
        return res

    def Plist(self):
        request = rpc_pb2.TContainerRequest()
        request.propertyList.CopyFrom(rpc_pb2.TContainerPropertyListRequest())
        return [item.name for item in self.call(request, self.timeout).propertyList.list]

    def Dlist(self):
        request = rpc_pb2.TContainerRequest()
        request.dataList.CopyFrom(rpc_pb2.TContainerDataListRequest())
        return [item.name for item in self.call(request, self.timeout).dataList.list]

    def Wait(self, containers, timeout=None):
        request = rpc_pb2.TContainerRequest()
        request.wait.name.extend(containers)
        if timeout is not None and timeout >= 0:
            request.wait.timeout = timeout

        resp = self.call(request, None)
        if resp.error != rpc_pb2.Success:
            raise exceptions.EError.Create(resp.error, resp.errorMsg)
        return resp.wait.name

    def ListVolumeProperties(self):
        request = rpc_pb2.TContainerRequest()
        request.listVolumeProperties.CopyFrom(rpc_pb2.TVolumePropertyListRequest())
        return self.call(request, self.timeout).volumePropertyList.properties

    def ListVolumes(self, path=None, container=None):
        request = rpc_pb2.TContainerRequest()
        request.listVolumes.CopyFrom(rpc_pb2.TVolumeListRequest())
        if path:
            request.listVolumes.path = path
        if container:
            request.listVolumes.container = container
        return self.call(request, self.timeout).volumeList.volumes

    def CreateVolume(self, path=None, **properties):
        request = rpc_pb2.TContainerRequest()
        request.createVolume.CopyFrom(rpc_pb2.TVolumeCreateRequest())
        if path:
            request.createVolume.path = path
        for name, value in properties.iteritems():
            prop = request.createVolume.properties.add()
            prop.name, prop.value = name, value
        return self.call(request, self.timeout).volume

    def LinkVolume(self, path, container):
        request = rpc_pb2.TContainerRequest()
        request.linkVolume.path = path
        request.linkVolume.container = container
        self.call(request, self.timeout)

    def UnlinkVolume(self, path, container=None):
        request = rpc_pb2.TContainerRequest()
        request.unlinkVolume.path = path
        if container:
            request.unlinkVolume.container = container
        self.call(request, self.timeout)

    def TuneVolume(self, path, **properties):
        request = rpc_pb2.TContainerRequest()
        request.tuneVolume.CopyFrom(rpc_pb2.TVolumeTuneRequest())
        request.tuneVolume.path = path
        for name, value in properties.iteritems():
            prop = request.tuneVolume.properties.add()
            prop.name, prop.value = name, value
        self.call(request, self.timeout)

    def ImportLayer(self, layer, tarball, merge=False):
        request = rpc_pb2.TContainerRequest()
        request.importLayer.layer = layer
        request.importLayer.tarball = tarball
        request.importLayer.merge = merge
        self.call(request, self.timeout)

    def ExportLayer(self, volume, tarball):
        request = rpc_pb2.TContainerRequest()
        request.exportLayer.volume = volume
        request.exportLayer.tarball = tarball
        self.call(request, self.timeout)

    def RemoveLayer(self, layer):
        request = rpc_pb2.TContainerRequest()
        request.removeLayer.layer = layer
        self.call(request, self.timeout)

    def ListLayers(self):
        request = rpc_pb2.TContainerRequest()
        request.listLayers.CopyFrom(rpc_pb2.TLayerListRequest())
        return self.call(request, self.timeout).layers.layer


class Container(object):
    def __init__(self, rpc, name):
        self.rpc = rpc
        self.name = name

    def Start(self):
        self.rpc.Start(self.name)

    def Stop(self):
        self.rpc.Stop(self.name)

    def Kill(self, sig):
        self.rpc.Kill(self.name, sig)

    def Pause(self):
        self.rpc.Pause(self.name)

    def Resume(self):
        self.rpc.Resume(self.name)

    def Get(self, variables):
        return self.rpc.Get([self.name], variables)[self.name]

    def GetProperties(self):
        return self.Get(self.rpc.Plist())

    def GetProperty(self, property):
        # TODO make real property getters/setters
        return self.rpc.GetProperty(self.name, property)

    def SetProperty(self, property, value):
        self.rpc.SetProperty(self.name, property, value)

    def GetData(self, data):
        return self.rpc.GetData(self.name, data)

    def Wait(self, timeout=None):
        return self.rpc.Wait([self.name], timeout)

    def __str__(self):
        return 'Container `{}`'.format(self.name)

    def Destroy(self):
        self.rpc.Destroy(self.name)


class Layer(object):
    def __init__(self, rpc, name):
        self.rpc = rpc
        self.name = name

    def __str__(self):
        return 'Layer `{}`'.format(self.name)

    def Merge(self, tarball):
        self.rpc.ImportLayer(self.name, tarball, merge=True)

    def Remove(self):
        self.rpc.RemoveLayer(self.name)


class Volume(object):
    def __init__(self, rpc, path):
        self.rpc = rpc
        self.path = path

    def __str__(self):
        return 'Volume `{}`'.format(self.path)

    def GetProperties(self):
        return {p.name: p.value for p in self.rpc.ListVolumes(path=self.path)[0].properties}

    def GetProperty(self, name):
        return self.GetProperties()[name]

    def GetContainers(self):
        return [Container(self.rpc, c) for c in self.rpc.ListVolumes(path=self.path)[0].containers]

    def GetLayers(self):
        layers = self.GetProperty('layers')
        layers = layers.split(';') if layers else []
        return [Layer(self.rpc, l) for l in layers]

    def Link(self, container):
        if isinstance(container, Container):
            container = container.name
        self.rpc.LinkVolume(self.path, container)

    def Unlink(self, container=None):
        if isinstance(container, Container):
            container = container.name
        self.rpc.UnlinkVolume(self.path, container)

    def Tune(self, **properties):
        self.rpc.TuneVolume(self.path, **properties)

    def Export(self, tarball):
        self.rpc.ExportLayer(self.path, tarball)


class Connection(object):
    def __init__(self,
                 socket_path='/run/portod.socket',
                 timeout=5,
                 socket_constructor=socket.socket,
                 lock_constructor=threading.Lock):
        self.rpc = _RPC(socket_path=socket_path,
                        timeout=timeout,
                        socket_constructor=socket_constructor,
                        lock_constructor=lock_constructor)

    def connect(self):
        self.rpc.connect()

    def disconnect(self):
        self.rpc.disconnect()

    def List(self):
        return self.rpc.List()

    def ListContainers(self):
        return [Container(self.rpc, name) for name in self.rpc.List()]

    def Find(self, name):
        if name not in self.List():
            raise exceptions.ContainerDoesNotExist("no such container")
        return Container(self.rpc, name)

    def Create(self, name):
        self.rpc.Create(name)
        return Container(self.rpc, name)

    def CreateWeakContainer(self, name):
        self.rpc.CreateWeak(name)
        return Container(self.rpc, name)

    def Destroy(self, container):
        if isinstance(container, Container):
            container = container.name
        self.rpc.Destroy(container)

    def Start(self, name):
        self.rpc.Start(name)

    def Stop(self, name):
        self.rpc.Stop(name)

    def Kill(self, name, sig):
        self.rpc.Kill(name, sig)

    def Pause(self, name):
        self.rpc.Pause(name)

    def Resume(self, name):
        self.rpc.Resume(name)

    def Get(self, containers, variables):
        return self.rpc.Get(containers, variables)

    def GetProperty(self, name, property):
        return self.rpc.GetProperty(name, property)

    def SetProperty(self, name, property, value):
        self.rpc.SetProperty(name, property, value)

    def GetData(self, name, data):
        return self.rpc.GetData(name, data)

    def Plist(self):
        return self.rpc.Plist()

    def Dlist(self):
        return self.rpc.Dlist()

    def Vlist(self):
        return [prop.name for prop in self.rpc.ListVolumeProperties()]

    def Wait(self, containers, timeout=None):
        return self.rpc.Wait(containers, timeout)

    def CreateVolume(self, path=None, layers=[], **properties):
        if layers:
            layers = [l.name if isinstance(l, Layer) else l for l in layers]
            properties['layers'] = ';'.join(layers)
        return Volume(self.rpc, self.rpc.CreateVolume(path, **properties).path)

    def FindVolume(self, path):
        self.rpc.ListVolumes(path=path)
        return Volume(self.rpc, path)

    def DestroyVolume(self, volume, containers=None):
        path = volume.path if isinstance(volume, Volume) else volume
        if containers is None:
            containers = self.rpc.ListVolumes(path=path)[0].containers
        for container in containers:
            try:
                self.rpc.UnlinkVolume(path, container)
            except exceptions.VolumeNotLinked:
                pass
        try:
            self.rpc.ListVolumes(path=path)
            raise exceptions.Busy("layer `%s` is busy" % path)
        except exceptions.VolumeNotFound:
            pass

    def ListVolumes(self, container=None):
        if isinstance(container, Container):
            container = container.name
        return [Volume(self.rpc, v.path) for v in self.rpc.ListVolumes(container=container)]

    def TuneVolume(self, path, **properties):
        self.rpc.TuneVolume(path, **properties)

    def ImportLayer(self, name, tarball):
        self.rpc.ImportLayer(name, tarball)
        return Layer(self.rpc, name)

    def FindLayer(self, layer):
        if layer not in self.rpc.ListLayers():
            raise exceptions.LayerNotFound("layer `%s` not found" % layer)
        return Layer(self.rpc, layer)

    def RemoveLayer(self, name):
        self.rpc.RemoveLayer(name)

    def ListLayers(self):
        return [Layer(self.rpc, l) for l in self.rpc.ListLayers()]

    def ConvertPath(self, path, source, destination):
        return self.rpc.ConvertPath(self.rpc, path, source, destination)

# Example:
# from porto import *
# conn = Connection()
# conn.connect()
# print conn.Create('test')
# print conn.Plist()
# print conn.Dlist()
# print conn.GetProperty('test', 'command')
# print conn.GetData('/', 'state')
# print conn.List()
# print conn.Destroy('test')
#
# container = conn.Create('test2')
# print container.GetProperty('command')
# print container.GetData('state')
# print container.Get(['command', 'state'])
# conn.Destroy(container)
# conn.disconnect()



from . import rpc_pb2


class SocketError(Exception):
    pass


class SocketTimeout(Exception):
    pass


class UnknownError(Exception):
    def __str__(self):
        return '{}: {}'.format(self.__class__.__name__, self.message)


class EError(Exception):
    EID = None
    __TYPES__ = {}

    class __metaclass__(type):
        def __new__(mcs, cls, bases, dct):
            new_class = type.__new__(mcs, cls, bases, dct)

            eid = dct.get('EID')
            if eid is not None:
                EError.__TYPES__[eid] = new_class

            return new_class

    @classmethod
    def Create(cls, eid, msg):
        e_class = cls.__TYPES__.get(eid)
        if e_class is not None:
            return e_class(msg)
        return UnknownError(msg)

    def __str__(self):
        return '{}: {}'.format(self.__class__.__name__, self.message)


class InvalidMethod(EError):
    EID = rpc_pb2.InvalidMethod


class ContainerAlreadyExists(EError):
    EID = rpc_pb2.ContainerAlreadyExists


class ContainerDoesNotExist(EError):
    EID = rpc_pb2.ContainerDoesNotExist


class InvalidProperty(EError):
    EID = rpc_pb2.InvalidProperty


class InvalidData(EError):
    EID = rpc_pb2.InvalidData


class InvalidValue(EError):
    EID = rpc_pb2.InvalidValue


class InvalidState(EError):
    EID = rpc_pb2.InvalidState


class NotSupported(EError):
    EID = rpc_pb2.NotSupported


class ResourceNotAvailable(EError):
    EID = rpc_pb2.ResourceNotAvailable


class PermissionError(EError):
    EID = rpc_pb2.Permission


class VolumeAlreadyExists(EError):
    EID = rpc_pb2.VolumeAlreadyExists


class VolumeNotFound(EError):
    EID = rpc_pb2.VolumeNotFound


class VolumeAlreadyLinked(EError):
    EID = rpc_pb2.VolumeAlreadyLinked


class VolumeNotLinked(EError):
    EID = rpc_pb2.VolumeNotLinked


class LayerAlreadyExists(EError):
    EID = rpc_pb2.LayerAlreadyExists


class LayerNotFound(EError):
    EID = rpc_pb2.LayerNotFound


class NoSpace(EError):
    EID = rpc_pb2.NoSpace


class Busy(EError):
    EID = rpc_pb2.Busy



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rpc.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rpc.proto',
  package='rpc',
  serialized_pb='\n\trpc.proto\x12\x03rpc\"\'\n\x17TContainerCreateRequest\x12\x0c\n\x04name\x18\x01 \x02(\t\"(\n\x18TContainerDestroyRequest\x12\x0c\n\x04name\x18\x01 \x02(\t\"\x17\n\x15TContainerListRequest\">\n\x1cTContainerGetPropertyRequest\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x10\n\x08property\x18\x02 \x02(\t\"M\n\x1cTContainerSetPropertyRequest\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x10\n\x08property\x18\x02 \x02(\t\x12\r\n\x05value\x18\x03 \x02(\t\"6\n\x18TContainerGetDataRequest\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x02(\t\"&\n\x16TContainerStartRequest\x12\x0c\n\x04name\x18\x01 \x02(\t\"%\n\x15TContainerStopRequest\x12\x0c\n\x04name\x18\x01 \x02(\t\"&\n\x16TContainerPauseRequest\x12\x0c\n\x04name\x18\x01 \x02(\t\"\'\n\x17TContainerResumeRequest\x12\x0c\n\x04name\x18\x01 \x02(\t\"\x1f\n\x1dTContainerPropertyListRequest\"\x1b\n\x19TContainerDataListRequest\"2\n\x15TContainerKillRequest\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x0b\n\x03sig\x18\x02 \x02(\x05\"\x11\n\x0fTVersionRequest\"H\n\x13TConvertPathRequest\x12\x0c\n\x04path\x18\x01 \x02(\t\x12\x0e\n\x06source\x18\x02 \x02(\t\x12\x13\n\x0b\x64\x65stination\x18\x03 \x02(\t\"6\n\x14TContainerGetRequest\x12\x0c\n\x04name\x18\x01 \x03(\t\x12\x10\n\x08variable\x18\x02 \x03(\t\"6\n\x15TContainerWaitRequest\x12\x0c\n\x04name\x18\x01 \x03(\t\x12\x0f\n\x07timeout\x18\x02 \x01(\r\"\xbe\n\n\x11TContainerRequest\x12,\n\x06\x63reate\x18\x01 \x01(\x0b\x32\x1c.rpc.TContainerCreateRequest\x12.\n\x07\x64\x65stroy\x18\x02 \x01(\x0b\x32\x1d.rpc.TContainerDestroyRequest\x12(\n\x04list\x18\x03 \x01(\x0b\x32\x1a.rpc.TContainerListRequest\x12\x36\n\x0bgetProperty\x18\x04 \x01(\x0b\x32!.rpc.TContainerGetPropertyRequest\x12\x36\n\x0bsetProperty\x18\x05 \x01(\x0b\x32!.rpc.TContainerSetPropertyRequest\x12.\n\x07getData\x18\x06 \x01(\x0b\x32\x1d.rpc.TContainerGetDataRequest\x12*\n\x05start\x18\x07 \x01(\x0b\x32\x1b.rpc.TContainerStartRequest\x12(\n\x04stop\x18\x08 \x01(\x0b\x32\x1a.rpc.TContainerStopRequest\x12*\n\x05pause\x18\t \x01(\x0b\x32\x1b.rpc.TContainerPauseRequest\x12,\n\x06resume\x18\n \x01(\x0b\x32\x1c.rpc.TContainerResumeRequest\x12\x38\n\x0cpropertyList\x18\x0b \x01(\x0b\x32\".rpc.TContainerPropertyListRequest\x12\x30\n\x08\x64\x61taList\x18\x0c \x01(\x0b\x32\x1e.rpc.TContainerDataListRequest\x12(\n\x04kill\x18\r \x01(\x0b\x32\x1a.rpc.TContainerKillRequest\x12%\n\x07version\x18\x0e \x01(\x0b\x32\x14.rpc.TVersionRequest\x12&\n\x03get\x18\x0f \x01(\x0b\x32\x19.rpc.TContainerGetRequest\x12(\n\x04wait\x18\x10 \x01(\x0b\x32\x1a.rpc.TContainerWaitRequest\x12\x30\n\ncreateWeak\x18\x11 \x01(\x0b\x32\x1c.rpc.TContainerCreateRequest\x12=\n\x14listVolumeProperties\x18g \x01(\x0b\x32\x1f.rpc.TVolumePropertyListRequest\x12/\n\x0c\x63reateVolume\x18h \x01(\x0b\x32\x19.rpc.TVolumeCreateRequest\x12+\n\nlinkVolume\x18i \x01(\x0b\x32\x17.rpc.TVolumeLinkRequest\x12/\n\x0cunlinkVolume\x18j \x01(\x0b\x32\x19.rpc.TVolumeUnlinkRequest\x12,\n\x0blistVolumes\x18k \x01(\x0b\x32\x17.rpc.TVolumeListRequest\x12+\n\ntuneVolume\x18l \x01(\x0b\x32\x17.rpc.TVolumeTuneRequest\x12-\n\x0bimportLayer\x18n \x01(\x0b\x32\x18.rpc.TLayerImportRequest\x12-\n\x0bremoveLayer\x18o \x01(\x0b\x32\x18.rpc.TLayerRemoveRequest\x12*\n\nlistLayers\x18p \x01(\x0b\x32\x16.rpc.TLayerListRequest\x12-\n\x0b\x65xportLayer\x18q \x01(\x0b\x32\x18.rpc.TLayerExportRequest\x12.\n\x0b\x63onvertPath\x18\xc8\x01 \x01(\x0b\x32\x18.rpc.TConvertPathRequest\"&\n\x16TContainerListResponse\x12\x0c\n\x04name\x18\x01 \x03(\t\".\n\x1dTContainerGetPropertyResponse\x12\r\n\x05value\x18\x01 \x02(\t\"*\n\x19TContainerGetDataResponse\x12\r\n\x05value\x18\x01 \x02(\t\"\xaa\x01\n\x1eTContainerPropertyListResponse\x12M\n\x04list\x18\x01 \x03(\x0b\x32?.rpc.TContainerPropertyListResponse.TContainerPropertyListEntry\x1a\x39\n\x1bTContainerPropertyListEntry\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x0c\n\x04\x64\x65sc\x18\x02 \x02(\t\"\x9a\x01\n\x1aTContainerDataListResponse\x12\x45\n\x04list\x18\x01 \x03(\x0b\x32\x37.rpc.TContainerDataListResponse.TContainerDataListEntry\x1a\x35\n\x17TContainerDataListEntry\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x0c\n\x04\x64\x65sc\x18\x02 \x02(\t\"1\n\x10TVersionResponse\x12\x0b\n\x03tag\x18\x01 \x02(\t\x12\x10\n\x08revision\x18\x02 \x02(\t\"\xba\x02\n\x15TContainerGetResponse\x12\x42\n\x04list\x18\x01 \x03(\x0b\x32\x34.rpc.TContainerGetResponse.TContainerGetListResponse\x1ak\n\x1aTContainerGetValueResponse\x12\x10\n\x08variable\x18\x01 \x02(\t\x12\x1a\n\x05\x65rror\x18\x02 \x01(\x0e\x32\x0b.rpc.EError\x12\x10\n\x08\x65rrorMsg\x18\x03 \x01(\t\x12\r\n\x05value\x18\x04 \x01(\t\x1ap\n\x19TContainerGetListResponse\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x45\n\x06keyval\x18\x02 \x03(\x0b\x32\x35.rpc.TContainerGetResponse.TContainerGetValueResponse\"&\n\x16TContainerWaitResponse\x12\x0c\n\x04name\x18\x01 \x02(\t\"$\n\x14TConvertPathResponse\x12\x0c\n\x04path\x18\x01 \x02(\t\"\xaf\x05\n\x12TContainerResponse\x12\x1a\n\x05\x65rror\x18\x01 \x02(\x0e\x32\x0b.rpc.EError\x12\x10\n\x08\x65rrorMsg\x18\x02 \x01(\t\x12)\n\x04list\x18\x03 \x01(\x0b\x32\x1b.rpc.TContainerListResponse\x12\x37\n\x0bgetProperty\x18\x04 \x01(\x0b\x32\".rpc.TContainerGetPropertyResponse\x12/\n\x07getData\x18\x05 \x01(\x0b\x32\x1e.rpc.TContainerGetDataResponse\x12\x39\n\x0cpropertyList\x18\x06 \x01(\x0b\x32#.rpc.TContainerPropertyListResponse\x12\x31\n\x08\x64\x61taList\x18\x07 \x01(\x0b\x32\x1f.rpc.TContainerDataListResponse\x12&\n\x07version\x18\x08 \x01(\x0b\x32\x15.rpc.TVersionResponse\x12,\n\nvolumeList\x18\t \x01(\x0b\x32\x18.rpc.TVolumeListResponse\x12\'\n\x03get\x18\n \x01(\x0b\x32\x1a.rpc.TContainerGetResponse\x12)\n\x04wait\x18\x0b \x01(\x0b\x32\x1b.rpc.TContainerWaitResponse\x12<\n\x12volumePropertyList\x18\x0c \x01(\x0b\x32 .rpc.TVolumePropertyListResponse\x12\'\n\x06volume\x18\r \x01(\x0b\x32\x17.rpc.TVolumeDescription\x12\'\n\x06layers\x18\x0e \x01(\x0b\x32\x17.rpc.TLayerListResponse\x12.\n\x0b\x63onvertPath\x18\x0f \x01(\x0b\x32\x19.rpc.TConvertPathResponse\".\n\x0fTVolumeProperty\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\r\n\x05value\x18\x02 \x02(\t\"8\n\x1aTVolumePropertyDescription\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x0c\n\x04\x64\x65sc\x18\x02 \x02(\t\"`\n\x12TVolumeDescription\x12\x0c\n\x04path\x18\x01 \x02(\t\x12(\n\nproperties\x18\x02 \x03(\x0b\x32\x14.rpc.TVolumeProperty\x12\x12\n\ncontainers\x18\x03 \x03(\t\"\x1c\n\x1aTVolumePropertyListRequest\"R\n\x1bTVolumePropertyListResponse\x12\x33\n\nproperties\x18\x01 \x03(\x0b\x32\x1f.rpc.TVolumePropertyDescription\"N\n\x14TVolumeCreateRequest\x12\x0c\n\x04path\x18\x01 \x01(\t\x12(\n\nproperties\x18\x02 \x03(\x0b\x32\x14.rpc.TVolumeProperty\"5\n\x12TVolumeLinkRequest\x12\x0c\n\x04path\x18\x01 \x02(\t\x12\x11\n\tcontainer\x18\x02 \x01(\t\"7\n\x14TVolumeUnlinkRequest\x12\x0c\n\x04path\x18\x01 \x02(\t\x12\x11\n\tcontainer\x18\x02 \x01(\t\"5\n\x12TVolumeListRequest\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x11\n\tcontainer\x18\x02 \x01(\t\"L\n\x12TVolumeTuneRequest\x12\x0c\n\x04path\x18\x01 \x02(\t\x12(\n\nproperties\x18\x02 \x03(\x0b\x32\x14.rpc.TVolumeProperty\"?\n\x13TVolumeListResponse\x12(\n\x07volumes\x18\x01 \x03(\x0b\x32\x17.rpc.TVolumeDescription\"D\n\x13TLayerImportRequest\x12\r\n\x05layer\x18\x01 \x02(\t\x12\x0f\n\x07tarball\x18\x02 \x02(\t\x12\r\n\x05merge\x18\x03 \x02(\x08\"6\n\x13TLayerExportRequest\x12\x0e\n\x06volume\x18\x01 \x02(\t\x12\x0f\n\x07tarball\x18\x02 \x02(\t\"$\n\x13TLayerRemoveRequest\x12\r\n\x05layer\x18\x01 \x02(\t\"\x13\n\x11TLayerListRequest\"#\n\x12TLayerListResponse\x12\r\n\x05layer\x18\x01 \x03(\t*\x9c\x03\n\x06\x45\x45rror\x12\x0b\n\x07Success\x10\x00\x12\x0b\n\x07Unknown\x10\x01\x12\x11\n\rInvalidMethod\x10\x02\x12\x1a\n\x16\x43ontainerAlreadyExists\x10\x03\x12\x19\n\x15\x43ontainerDoesNotExist\x10\x04\x12\x13\n\x0fInvalidProperty\x10\x05\x12\x0f\n\x0bInvalidData\x10\x06\x12\x10\n\x0cInvalidValue\x10\x07\x12\x10\n\x0cInvalidState\x10\x08\x12\x10\n\x0cNotSupported\x10\t\x12\x18\n\x14ResourceNotAvailable\x10\n\x12\x0e\n\nPermission\x10\x0b\x12\x17\n\x13VolumeAlreadyExists\x10\x0c\x12\x12\n\x0eVolumeNotFound\x10\r\x12\x0b\n\x07NoSpace\x10\x0e\x12\x08\n\x04\x42usy\x10\x0f\x12\x17\n\x13VolumeAlreadyLinked\x10\x10\x12\x13\n\x0fVolumeNotLinked\x10\x11\x12\x16\n\x12LayerAlreadyExists\x10\x12\x12\x11\n\rLayerNotFound\x10\x13\x12\x0b\n\x06Queued\x10\xe8\x07')

_EERROR = _descriptor.EnumDescriptor(
  name='EError',
  full_name='rpc.EError',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Success', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Unknown', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='InvalidMethod', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ContainerAlreadyExists', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ContainerDoesNotExist', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='InvalidProperty', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='InvalidData', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='InvalidValue', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='InvalidState', index=8, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NotSupported', index=9, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ResourceNotAvailable', index=10, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Permission', index=11, number=11,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VolumeAlreadyExists', index=12, number=12,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VolumeNotFound', index=13, number=13,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NoSpace', index=14, number=14,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Busy', index=15, number=15,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VolumeAlreadyLinked', index=16, number=16,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VolumeNotLinked', index=17, number=17,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LayerAlreadyExists', index=18, number=18,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LayerNotFound', index=19, number=19,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Queued', index=20, number=1000,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=4678,
  serialized_end=5090,
)

EError = enum_type_wrapper.EnumTypeWrapper(_EERROR)
Success = 0
Unknown = 1
InvalidMethod = 2
ContainerAlreadyExists = 3
ContainerDoesNotExist = 4
InvalidProperty = 5
InvalidData = 6
InvalidValue = 7
InvalidState = 8
NotSupported = 9
ResourceNotAvailable = 10
Permission = 11
VolumeAlreadyExists = 12
VolumeNotFound = 13
NoSpace = 14
Busy = 15
VolumeAlreadyLinked = 16
VolumeNotLinked = 17
LayerAlreadyExists = 18
LayerNotFound = 19
Queued = 1000



_TCONTAINERCREATEREQUEST = _descriptor.Descriptor(
  name='TContainerCreateRequest',
  full_name='rpc.TContainerCreateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='rpc.TContainerCreateRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=18,
  serialized_end=57,
)


_TCONTAINERDESTROYREQUEST = _descriptor.Descriptor(
  name='TContainerDestroyRequest',
  full_name='rpc.TContainerDestroyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='rpc.TContainerDestroyRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=59,
  serialized_end=99,
)


_TCONTAINERLISTREQUEST = _descriptor.Descriptor(
  name='TContainerListRequest',
  full_name='rpc.TContainerListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=101,
  serialized_end=124,
)


_TCONTAINERGETPROPERTYREQUEST = _descriptor.Descriptor(
  name='TContainerGetPropertyRequest',
  full_name='rpc.TContainerGetPropertyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='rpc.TContainerGetPropertyRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='property', full_name='rpc.TContainerGetPropertyRequest.property', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=126,
  serialized_end=188,
)


_TCONTAINERSETPROPERTYREQUEST = _descriptor.Descriptor(
  name='TContainerSetPropertyRequest',
  full_name='rpc.TContainerSetPropertyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='rpc.TContainerSetPropertyRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='property', full_name='rpc.TContainerSetPropertyRequest.property', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='rpc.TContainerSetPropertyRequest.value', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=190,
  serialized_end=267,
)


_TCONTAINERGETDATAREQUEST = _descriptor.Descriptor(
  name='TContainerGetDataRequest',
  full_name='rpc.TContainerGetDataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='rpc.TContainerGetDataRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='data', full_name='rpc.TContainerGetDataRequest.data', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=269,
  serialized_end=323,
)


_TCONTAINERSTARTREQUEST = _descriptor.Descriptor(
  name='TContainerStartRequest',
  full_name='rpc.TContainerStartRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='rpc.TContainerStartRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=325,
  serialized_end=363,
)


_TCONTAINERSTOPREQUEST = _descriptor.Descriptor(
  name='TContainerStopRequest',
  full_name='rpc.TContainerStopRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='rpc.TContainerStopRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=365,
  serialized_end=402,
)


_TCONTAINERPAUSEREQUEST = _descriptor.Descriptor(
  name='TContainerPauseRequest',
  full_name='rpc.TContainerPauseRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='rpc.TContainerPauseRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=404,
  serialized_end=442,
)


_TCONTAINERRESUMEREQUEST = _descriptor.Descriptor(
  name='TContainerResumeRequest',
  full_name='rpc.TContainerResumeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='rpc.TContainerResumeRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=444,
  serialized_end=483,
)


_TCONTAINERPROPERTYLISTREQUEST = _descriptor.Descriptor(
  name='TContainerPropertyListRequest',
  full_name='rpc.TContainerPropertyListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=485,
  serialized_end=516,
)


_TCONTAINERDATALISTREQUEST = _descriptor.Descriptor(
  name='TContainerDataListRequest',
  full_name='rpc.TContainerDataListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=518,
  serialized_end=545,
)


_TCONTAINERKILLREQUEST = _descriptor.Descriptor(
  name='TContainerKillRequest',
  full_name='rpc.TContainerKillRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='rpc.TContainerKillRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sig', full_name='rpc.TContainerKillRequest.sig', index=1,
      number=2, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=547,
  serialized_end=597,
)


_TVERSIONREQUEST = _descriptor.Descriptor(
  name='TVersionRequest',
  full_name='rpc.TVersionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=599,
  serialized_end=616,
)


_TCONVERTPATHREQUEST = _descriptor.Descriptor(
  name='TConvertPathRequest',
  full_name='rpc.TConvertPathRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='rpc.TConvertPathRequest.path', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='source', full_name='rpc.TConvertPathRequest.source', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='destination', full_name='rpc.TConvertPathRequest.destination', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=618,
  serialized_end=690,
)


_TCONTAINERGETREQUEST = _descriptor.Descriptor(
  name='TContainerGetRequest',
  full_name='rpc.TContainerGetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='rpc.TContainerGetRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='variable', full_name='rpc.TContainerGetRequest.variable', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=692,
  serialized_end=746,
)


_TCONTAINERWAITREQUEST = _descriptor.Descriptor(
  name='TContainerWaitRequest',
  full_name='rpc.TContainerWaitRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='rpc.TContainerWaitRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='rpc.TContainerWaitRequest.timeout', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=748,
  serialized_end=802,
)


_TCONTAINERREQUEST = _descriptor.Descriptor(
  name='TContainerRequest',
  full_name='rpc.TContainerRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='create', full_name='rpc.TContainerRequest.create', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='destroy', full_name='rpc.TContainerRequest.destroy', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='list', full_name='rpc.TContainerRequest.list', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='getProperty', full_name='rpc.TContainerRequest.getProperty', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='setProperty', full_name='rpc.TContainerRequest.setProperty', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='getData', full_name='rpc.TContainerRequest.getData', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='start', full_name='rpc.TContainerRequest.start', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stop', full_name='rpc.TContainerRequest.stop', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pause', full_name='rpc.TContainerRequest.pause', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='resume', full_name='rpc.TContainerRequest.resume', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='propertyList', full_name='rpc.TContainerRequest.propertyList', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='dataList', full_name='rpc.TContainerRequest.dataList', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='kill', full_name='rpc.TContainerRequest.kill', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='version', full_name='rpc.TContainerRequest.version', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='get', full_name='rpc.TContainerRequest.get', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='wait', full_name='rpc.TContainerRequest.wait', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='createWeak', full_name='rpc.TContainerRequest.createWeak', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='listVolumeProperties', full_name='rpc.TContainerRequest.listVolumeProperties', index=17,
      number=103, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='createVolume', full_name='rpc.TContainerRequest.createVolume', index=18,
      number=104, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='linkVolume', full_name='rpc.TContainerRequest.linkVolume', index=19,
      number=105, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='unlinkVolume', full_name='rpc.TContainerRequest.unlinkVolume', index=20,
      number=106, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='listVolumes', full_name='rpc.TContainerRequest.listVolumes', index=21,
      number=107, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tuneVolume', full_name='rpc.TContainerRequest.tuneVolume', index=22,
      number=108, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='importLayer', full_name='rpc.TContainerRequest.importLayer', index=23,
      number=110, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='removeLayer', full_name='rpc.TContainerRequest.removeLayer', index=24,
      number=111, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='listLayers', full_name='rpc.TContainerRequest.listLayers', index=25,
      number=112, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='exportLayer', full_name='rpc.TContainerRequest.exportLayer', index=26,
      number=113, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='convertPath', full_name='rpc.TContainerRequest.convertPath', index=27,
      number=200, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=805,
  serialized_end=2147,
)


_TCONTAINERLISTRESPONSE = _descriptor.Descriptor(
  name='TContainerListResponse',
  full_name='rpc.TContainerListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='rpc.TContainerListResponse.name', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=2149,
  serialized_end=2187,
)


_TCONTAINERGETPROPERTYRESPONSE = _descriptor.Descriptor(
  name='TContainerGetPropertyResponse',
  full_name='rpc.TContainerGetPropertyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='rpc.TContainerGetPropertyResponse.value', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=2189,
  serialized_end=2235,
)


_TCONTAINERGETDATARESPONSE = _descriptor.Descriptor(
  name='TContainerGetDataResponse',
  full_name='rpc.TContainerGetDataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='rpc.TContainerGetDataResponse.value', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=2237,
  serialized_end=2279,
)


_TCONTAINERPROPERTYLISTRESPONSE_TCONTAINERPROPERTYLISTENTRY = _descriptor.Descriptor(
  name='TContainerPropertyListEntry',
  full_name='rpc.TContainerPropertyListResponse.TContainerPropertyListEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='rpc.TContainerPropertyListResponse.TContainerPropertyListEntry.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='desc', full_name='rpc.TContainerPropertyListResponse.TContainerPropertyListEntry.desc', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=2395,
  serialized_end=2452,
)

_TCONTAINERPROPERTYLISTRESPONSE = _descriptor.Descriptor(
  name='TContainerPropertyListResponse',
  full_name='rpc.TContainerPropertyListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='list', full_name='rpc.TContainerPropertyListResponse.list', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_TCONTAINERPROPERTYLISTRESPONSE_TCONTAINERPROPERTYLISTENTRY, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=2282,
  serialized_end=2452,
)


_TCONTAINERDATALISTRESPONSE_TCONTAINERDATALISTENTRY = _descriptor.Descriptor(
  name='TContainerDataListEntry',
  full_name='rpc.TContainerDataListResponse.TContainerDataListEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='rpc.TContainerDataListResponse.TContainerDataListEntry.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='desc', full_name='rpc.TContainerDataListResponse.TContainerDataListEntry.desc', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=2556,
  serialized_end=2609,
)

_TCONTAINERDATALISTRESPONSE = _descriptor.Descriptor(
  name='TContainerDataListResponse',
  full_name='rpc.TContainerDataListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='list', full_name='rpc.TContainerDataListResponse.list', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_TCONTAINERDATALISTRESPONSE_TCONTAINERDATALISTENTRY, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=2455,
  serialized_end=2609,
)


_TVERSIONRESPONSE = _descriptor.Descriptor(
  name='TVersionResponse',
  full_name='rpc.TVersionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tag', full_name='rpc.TVersionResponse.tag', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='revision', full_name='rpc.TVersionResponse.revision', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=2611,
  serialized_end=2660,
)


_TCONTAINERGETRESPONSE_TCONTAINERGETVALUERESPONSE = _descriptor.Descriptor(
  name='TContainerGetValueResponse',
  full_name='rpc.TContainerGetResponse.TContainerGetValueResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='variable', full_name='rpc.TContainerGetResponse.TContainerGetValueResponse.variable', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='error', full_name='rpc.TContainerGetResponse.TContainerGetValueResponse.error', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='errorMsg', full_name='rpc.TContainerGetResponse.TContainerGetValueResponse.errorMsg', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='rpc.TContainerGetResponse.TContainerGetValueResponse.value', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=2756,
  serialized_end=2863,
)

_TCONTAINERGETRESPONSE_TCONTAINERGETLISTRESPONSE = _descriptor.Descriptor(
  name='TContainerGetListResponse',
  full_name='rpc.TContainerGetResponse.TContainerGetListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='rpc.TContainerGetResponse.TContainerGetListResponse.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='keyval', full_name='rpc.TContainerGetResponse.TContainerGetListResponse.keyval', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=2865,
  serialized_end=2977,
)

_TCONTAINERGETRESPONSE = _descriptor.Descriptor(
  name='TContainerGetResponse',
  full_name='rpc.TContainerGetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='list', full_name='rpc.TContainerGetResponse.list', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_TCONTAINERGETRESPONSE_TCONTAINERGETVALUERESPONSE, _TCONTAINERGETRESPONSE_TCONTAINERGETLISTRESPONSE, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=2663,
  serialized_end=2977,
)


_TCONTAINERWAITRESPONSE = _descriptor.Descriptor(
  name='TContainerWaitResponse',
  full_name='rpc.TContainerWaitResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='rpc.TContainerWaitResponse.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=2979,
  serialized_end=3017,
)


_TCONVERTPATHRESPONSE = _descriptor.Descriptor(
  name='TConvertPathResponse',
  full_name='rpc.TConvertPathResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='rpc.TConvertPathResponse.path', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=3019,
  serialized_end=3055,
)


_TCONTAINERRESPONSE = _descriptor.Descriptor(
  name='TContainerResponse',
  full_name='rpc.TContainerResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error', full_name='rpc.TContainerResponse.error', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='errorMsg', full_name='rpc.TContainerResponse.errorMsg', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='list', full_name='rpc.TContainerResponse.list', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='getProperty', full_name='rpc.TContainerResponse.getProperty', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='getData', full_name='rpc.TContainerResponse.getData', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='propertyList', full_name='rpc.TContainerResponse.propertyList', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='dataList', full_name='rpc.TContainerResponse.dataList', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='version', full_name='rpc.TContainerResponse.version', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='volumeList', full_name='rpc.TContainerResponse.volumeList', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='get', full_name='rpc.TContainerResponse.get', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='wait', full_name='rpc.TContainerResponse.wait', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='volumePropertyList', full_name='rpc.TContainerResponse.volumePropertyList', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='volume', full_name='rpc.TContainerResponse.volume', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='layers', full_name='rpc.TContainerResponse.layers', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='convertPath', full_name='rpc.TContainerResponse.convertPath', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=3058,
  serialized_end=3745,
)


_TVOLUMEPROPERTY = _descriptor.Descriptor(
  name='TVolumeProperty',
  full_name='rpc.TVolumeProperty',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='rpc.TVolumeProperty.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='rpc.TVolumeProperty.value', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=3747,
  serialized_end=3793,
)


_TVOLUMEPROPERTYDESCRIPTION = _descriptor.Descriptor(
  name='TVolumePropertyDescription',
  full_name='rpc.TVolumePropertyDescription',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='rpc.TVolumePropertyDescription.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='desc', full_name='rpc.TVolumePropertyDescription.desc', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=3795,
  serialized_end=3851,
)


_TVOLUMEDESCRIPTION = _descriptor.Descriptor(
  name='TVolumeDescription',
  full_name='rpc.TVolumeDescription',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='rpc.TVolumeDescription.path', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='properties', full_name='rpc.TVolumeDescription.properties', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='containers', full_name='rpc.TVolumeDescription.containers', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=3853,
  serialized_end=3949,
)


_TVOLUMEPROPERTYLISTREQUEST = _descriptor.Descriptor(
  name='TVolumePropertyListRequest',
  full_name='rpc.TVolumePropertyListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=3951,
  serialized_end=3979,
)


_TVOLUMEPROPERTYLISTRESPONSE = _descriptor.Descriptor(
  name='TVolumePropertyListResponse',
  full_name='rpc.TVolumePropertyListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='properties', full_name='rpc.TVolumePropertyListResponse.properties', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=3981,
  serialized_end=4063,
)


_TVOLUMECREATEREQUEST = _descriptor.Descriptor(
  name='TVolumeCreateRequest',
  full_name='rpc.TVolumeCreateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='rpc.TVolumeCreateRequest.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='properties', full_name='rpc.TVolumeCreateRequest.properties', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=4065,
  serialized_end=4143,
)


_TVOLUMELINKREQUEST = _descriptor.Descriptor(
  name='TVolumeLinkRequest',
  full_name='rpc.TVolumeLinkRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='rpc.TVolumeLinkRequest.path', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='container', full_name='rpc.TVolumeLinkRequest.container', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=4145,
  serialized_end=4198,
)


_TVOLUMEUNLINKREQUEST = _descriptor.Descriptor(
  name='TVolumeUnlinkRequest',
  full_name='rpc.TVolumeUnlinkRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='rpc.TVolumeUnlinkRequest.path', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='container', full_name='rpc.TVolumeUnlinkRequest.container', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=4200,
  serialized_end=4255,
)


_TVOLUMELISTREQUEST = _descriptor.Descriptor(
  name='TVolumeListRequest',
  full_name='rpc.TVolumeListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='rpc.TVolumeListRequest.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='container', full_name='rpc.TVolumeListRequest.container', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=4257,
  serialized_end=4310,
)


_TVOLUMETUNEREQUEST = _descriptor.Descriptor(
  name='TVolumeTuneRequest',
  full_name='rpc.TVolumeTuneRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='rpc.TVolumeTuneRequest.path', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='properties', full_name='rpc.TVolumeTuneRequest.properties', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=4312,
  serialized_end=4388,
)


_TVOLUMELISTRESPONSE = _descriptor.Descriptor(
  name='TVolumeListResponse',
  full_name='rpc.TVolumeListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='volumes', full_name='rpc.TVolumeListResponse.volumes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=4390,
  serialized_end=4453,
)


_TLAYERIMPORTREQUEST = _descriptor.Descriptor(
  name='TLayerImportRequest',
  full_name='rpc.TLayerImportRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='layer', full_name='rpc.TLayerImportRequest.layer', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tarball', full_name='rpc.TLayerImportRequest.tarball', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='merge', full_name='rpc.TLayerImportRequest.merge', index=2,
      number=3, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=4455,
  serialized_end=4523,
)


_TLAYEREXPORTREQUEST = _descriptor.Descriptor(
  name='TLayerExportRequest',
  full_name='rpc.TLayerExportRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='volume', full_name='rpc.TLayerExportRequest.volume', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tarball', full_name='rpc.TLayerExportRequest.tarball', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=4525,
  serialized_end=4579,
)


_TLAYERREMOVEREQUEST = _descriptor.Descriptor(
  name='TLayerRemoveRequest',
  full_name='rpc.TLayerRemoveRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='layer', full_name='rpc.TLayerRemoveRequest.layer', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=4581,
  serialized_end=4617,
)


_TLAYERLISTREQUEST = _descriptor.Descriptor(
  name='TLayerListRequest',
  full_name='rpc.TLayerListRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=4619,
  serialized_end=4638,
)


_TLAYERLISTRESPONSE = _descriptor.Descriptor(
  name='TLayerListResponse',
  full_name='rpc.TLayerListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='layer', full_name='rpc.TLayerListResponse.layer', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=4640,
  serialized_end=4675,
)

_TCONTAINERREQUEST.fields_by_name['create'].message_type = _TCONTAINERCREATEREQUEST
_TCONTAINERREQUEST.fields_by_name['destroy'].message_type = _TCONTAINERDESTROYREQUEST
_TCONTAINERREQUEST.fields_by_name['list'].message_type = _TCONTAINERLISTREQUEST
_TCONTAINERREQUEST.fields_by_name['getProperty'].message_type = _TCONTAINERGETPROPERTYREQUEST
_TCONTAINERREQUEST.fields_by_name['setProperty'].message_type = _TCONTAINERSETPROPERTYREQUEST
_TCONTAINERREQUEST.fields_by_name['getData'].message_type = _TCONTAINERGETDATAREQUEST
_TCONTAINERREQUEST.fields_by_name['start'].message_type = _TCONTAINERSTARTREQUEST
_TCONTAINERREQUEST.fields_by_name['stop'].message_type = _TCONTAINERSTOPREQUEST
_TCONTAINERREQUEST.fields_by_name['pause'].message_type = _TCONTAINERPAUSEREQUEST
_TCONTAINERREQUEST.fields_by_name['resume'].message_type = _TCONTAINERRESUMEREQUEST
_TCONTAINERREQUEST.fields_by_name['propertyList'].message_type = _TCONTAINERPROPERTYLISTREQUEST
_TCONTAINERREQUEST.fields_by_name['dataList'].message_type = _TCONTAINERDATALISTREQUEST
_TCONTAINERREQUEST.fields_by_name['kill'].message_type = _TCONTAINERKILLREQUEST
_TCONTAINERREQUEST.fields_by_name['version'].message_type = _TVERSIONREQUEST
_TCONTAINERREQUEST.fields_by_name['get'].message_type = _TCONTAINERGETREQUEST
_TCONTAINERREQUEST.fields_by_name['wait'].message_type = _TCONTAINERWAITREQUEST
_TCONTAINERREQUEST.fields_by_name['createWeak'].message_type = _TCONTAINERCREATEREQUEST
_TCONTAINERREQUEST.fields_by_name['listVolumeProperties'].message_type = _TVOLUMEPROPERTYLISTREQUEST
_TCONTAINERREQUEST.fields_by_name['createVolume'].message_type = _TVOLUMECREATEREQUEST
_TCONTAINERREQUEST.fields_by_name['linkVolume'].message_type = _TVOLUMELINKREQUEST
_TCONTAINERREQUEST.fields_by_name['unlinkVolume'].message_type = _TVOLUMEUNLINKREQUEST
_TCONTAINERREQUEST.fields_by_name['listVolumes'].message_type = _TVOLUMELISTREQUEST
_TCONTAINERREQUEST.fields_by_name['tuneVolume'].message_type = _TVOLUMETUNEREQUEST
_TCONTAINERREQUEST.fields_by_name['importLayer'].message_type = _TLAYERIMPORTREQUEST
_TCONTAINERREQUEST.fields_by_name['removeLayer'].message_type = _TLAYERREMOVEREQUEST
_TCONTAINERREQUEST.fields_by_name['listLayers'].message_type = _TLAYERLISTREQUEST
_TCONTAINERREQUEST.fields_by_name['exportLayer'].message_type = _TLAYEREXPORTREQUEST
_TCONTAINERREQUEST.fields_by_name['convertPath'].message_type = _TCONVERTPATHREQUEST
_TCONTAINERPROPERTYLISTRESPONSE_TCONTAINERPROPERTYLISTENTRY.containing_type = _TCONTAINERPROPERTYLISTRESPONSE;
_TCONTAINERPROPERTYLISTRESPONSE.fields_by_name['list'].message_type = _TCONTAINERPROPERTYLISTRESPONSE_TCONTAINERPROPERTYLISTENTRY
_TCONTAINERDATALISTRESPONSE_TCONTAINERDATALISTENTRY.containing_type = _TCONTAINERDATALISTRESPONSE;
_TCONTAINERDATALISTRESPONSE.fields_by_name['list'].message_type = _TCONTAINERDATALISTRESPONSE_TCONTAINERDATALISTENTRY
_TCONTAINERGETRESPONSE_TCONTAINERGETVALUERESPONSE.fields_by_name['error'].enum_type = _EERROR
_TCONTAINERGETRESPONSE_TCONTAINERGETVALUERESPONSE.containing_type = _TCONTAINERGETRESPONSE;
_TCONTAINERGETRESPONSE_TCONTAINERGETLISTRESPONSE.fields_by_name['keyval'].message_type = _TCONTAINERGETRESPONSE_TCONTAINERGETVALUERESPONSE
_TCONTAINERGETRESPONSE_TCONTAINERGETLISTRESPONSE.containing_type = _TCONTAINERGETRESPONSE;
_TCONTAINERGETRESPONSE.fields_by_name['list'].message_type = _TCONTAINERGETRESPONSE_TCONTAINERGETLISTRESPONSE
_TCONTAINERRESPONSE.fields_by_name['error'].enum_type = _EERROR
_TCONTAINERRESPONSE.fields_by_name['list'].message_type = _TCONTAINERLISTRESPONSE
_TCONTAINERRESPONSE.fields_by_name['getProperty'].message_type = _TCONTAINERGETPROPERTYRESPONSE
_TCONTAINERRESPONSE.fields_by_name['getData'].message_type = _TCONTAINERGETDATARESPONSE
_TCONTAINERRESPONSE.fields_by_name['propertyList'].message_type = _TCONTAINERPROPERTYLISTRESPONSE
_TCONTAINERRESPONSE.fields_by_name['dataList'].message_type = _TCONTAINERDATALISTRESPONSE
_TCONTAINERRESPONSE.fields_by_name['version'].message_type = _TVERSIONRESPONSE
_TCONTAINERRESPONSE.fields_by_name['volumeList'].message_type = _TVOLUMELISTRESPONSE
_TCONTAINERRESPONSE.fields_by_name['get'].message_type = _TCONTAINERGETRESPONSE
_TCONTAINERRESPONSE.fields_by_name['wait'].message_type = _TCONTAINERWAITRESPONSE
_TCONTAINERRESPONSE.fields_by_name['volumePropertyList'].message_type = _TVOLUMEPROPERTYLISTRESPONSE
_TCONTAINERRESPONSE.fields_by_name['volume'].message_type = _TVOLUMEDESCRIPTION
_TCONTAINERRESPONSE.fields_by_name['layers'].message_type = _TLAYERLISTRESPONSE
_TCONTAINERRESPONSE.fields_by_name['convertPath'].message_type = _TCONVERTPATHRESPONSE
_TVOLUMEDESCRIPTION.fields_by_name['properties'].message_type = _TVOLUMEPROPERTY
_TVOLUMEPROPERTYLISTRESPONSE.fields_by_name['properties'].message_type = _TVOLUMEPROPERTYDESCRIPTION
_TVOLUMECREATEREQUEST.fields_by_name['properties'].message_type = _TVOLUMEPROPERTY
_TVOLUMETUNEREQUEST.fields_by_name['properties'].message_type = _TVOLUMEPROPERTY
_TVOLUMELISTRESPONSE.fields_by_name['volumes'].message_type = _TVOLUMEDESCRIPTION
DESCRIPTOR.message_types_by_name['TContainerCreateRequest'] = _TCONTAINERCREATEREQUEST
DESCRIPTOR.message_types_by_name['TContainerDestroyRequest'] = _TCONTAINERDESTROYREQUEST
DESCRIPTOR.message_types_by_name['TContainerListRequest'] = _TCONTAINERLISTREQUEST
DESCRIPTOR.message_types_by_name['TContainerGetPropertyRequest'] = _TCONTAINERGETPROPERTYREQUEST
DESCRIPTOR.message_types_by_name['TContainerSetPropertyRequest'] = _TCONTAINERSETPROPERTYREQUEST
DESCRIPTOR.message_types_by_name['TContainerGetDataRequest'] = _TCONTAINERGETDATAREQUEST
DESCRIPTOR.message_types_by_name['TContainerStartRequest'] = _TCONTAINERSTARTREQUEST
DESCRIPTOR.message_types_by_name['TContainerStopRequest'] = _TCONTAINERSTOPREQUEST
DESCRIPTOR.message_types_by_name['TContainerPauseRequest'] = _TCONTAINERPAUSEREQUEST
DESCRIPTOR.message_types_by_name['TContainerResumeRequest'] = _TCONTAINERRESUMEREQUEST
DESCRIPTOR.message_types_by_name['TContainerPropertyListRequest'] = _TCONTAINERPROPERTYLISTREQUEST
DESCRIPTOR.message_types_by_name['TContainerDataListRequest'] = _TCONTAINERDATALISTREQUEST
DESCRIPTOR.message_types_by_name['TContainerKillRequest'] = _TCONTAINERKILLREQUEST
DESCRIPTOR.message_types_by_name['TVersionRequest'] = _TVERSIONREQUEST
DESCRIPTOR.message_types_by_name['TConvertPathRequest'] = _TCONVERTPATHREQUEST
DESCRIPTOR.message_types_by_name['TContainerGetRequest'] = _TCONTAINERGETREQUEST
DESCRIPTOR.message_types_by_name['TContainerWaitRequest'] = _TCONTAINERWAITREQUEST
DESCRIPTOR.message_types_by_name['TContainerRequest'] = _TCONTAINERREQUEST
DESCRIPTOR.message_types_by_name['TContainerListResponse'] = _TCONTAINERLISTRESPONSE
DESCRIPTOR.message_types_by_name['TContainerGetPropertyResponse'] = _TCONTAINERGETPROPERTYRESPONSE
DESCRIPTOR.message_types_by_name['TContainerGetDataResponse'] = _TCONTAINERGETDATARESPONSE
DESCRIPTOR.message_types_by_name['TContainerPropertyListResponse'] = _TCONTAINERPROPERTYLISTRESPONSE
DESCRIPTOR.message_types_by_name['TContainerDataListResponse'] = _TCONTAINERDATALISTRESPONSE
DESCRIPTOR.message_types_by_name['TVersionResponse'] = _TVERSIONRESPONSE
DESCRIPTOR.message_types_by_name['TContainerGetResponse'] = _TCONTAINERGETRESPONSE
DESCRIPTOR.message_types_by_name['TContainerWaitResponse'] = _TCONTAINERWAITRESPONSE
DESCRIPTOR.message_types_by_name['TConvertPathResponse'] = _TCONVERTPATHRESPONSE
DESCRIPTOR.message_types_by_name['TContainerResponse'] = _TCONTAINERRESPONSE
DESCRIPTOR.message_types_by_name['TVolumeProperty'] = _TVOLUMEPROPERTY
DESCRIPTOR.message_types_by_name['TVolumePropertyDescription'] = _TVOLUMEPROPERTYDESCRIPTION
DESCRIPTOR.message_types_by_name['TVolumeDescription'] = _TVOLUMEDESCRIPTION
DESCRIPTOR.message_types_by_name['TVolumePropertyListRequest'] = _TVOLUMEPROPERTYLISTREQUEST
DESCRIPTOR.message_types_by_name['TVolumePropertyListResponse'] = _TVOLUMEPROPERTYLISTRESPONSE
DESCRIPTOR.message_types_by_name['TVolumeCreateRequest'] = _TVOLUMECREATEREQUEST
DESCRIPTOR.message_types_by_name['TVolumeLinkRequest'] = _TVOLUMELINKREQUEST
DESCRIPTOR.message_types_by_name['TVolumeUnlinkRequest'] = _TVOLUMEUNLINKREQUEST
DESCRIPTOR.message_types_by_name['TVolumeListRequest'] = _TVOLUMELISTREQUEST
DESCRIPTOR.message_types_by_name['TVolumeTuneRequest'] = _TVOLUMETUNEREQUEST
DESCRIPTOR.message_types_by_name['TVolumeListResponse'] = _TVOLUMELISTRESPONSE
DESCRIPTOR.message_types_by_name['TLayerImportRequest'] = _TLAYERIMPORTREQUEST
DESCRIPTOR.message_types_by_name['TLayerExportRequest'] = _TLAYEREXPORTREQUEST
DESCRIPTOR.message_types_by_name['TLayerRemoveRequest'] = _TLAYERREMOVEREQUEST
DESCRIPTOR.message_types_by_name['TLayerListRequest'] = _TLAYERLISTREQUEST
DESCRIPTOR.message_types_by_name['TLayerListResponse'] = _TLAYERLISTRESPONSE

class TContainerCreateRequest(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TCONTAINERCREATEREQUEST

  # @@protoc_insertion_point(class_scope:rpc.TContainerCreateRequest)

class TContainerDestroyRequest(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TCONTAINERDESTROYREQUEST

  # @@protoc_insertion_point(class_scope:rpc.TContainerDestroyRequest)

class TContainerListRequest(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TCONTAINERLISTREQUEST

  # @@protoc_insertion_point(class_scope:rpc.TContainerListRequest)

class TContainerGetPropertyRequest(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TCONTAINERGETPROPERTYREQUEST

  # @@protoc_insertion_point(class_scope:rpc.TContainerGetPropertyRequest)

class TContainerSetPropertyRequest(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TCONTAINERSETPROPERTYREQUEST

  # @@protoc_insertion_point(class_scope:rpc.TContainerSetPropertyRequest)

class TContainerGetDataRequest(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TCONTAINERGETDATAREQUEST

  # @@protoc_insertion_point(class_scope:rpc.TContainerGetDataRequest)

class TContainerStartRequest(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TCONTAINERSTARTREQUEST

  # @@protoc_insertion_point(class_scope:rpc.TContainerStartRequest)

class TContainerStopRequest(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TCONTAINERSTOPREQUEST

  # @@protoc_insertion_point(class_scope:rpc.TContainerStopRequest)

class TContainerPauseRequest(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TCONTAINERPAUSEREQUEST

  # @@protoc_insertion_point(class_scope:rpc.TContainerPauseRequest)

class TContainerResumeRequest(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TCONTAINERRESUMEREQUEST

  # @@protoc_insertion_point(class_scope:rpc.TContainerResumeRequest)

class TContainerPropertyListRequest(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TCONTAINERPROPERTYLISTREQUEST

  # @@protoc_insertion_point(class_scope:rpc.TContainerPropertyListRequest)

class TContainerDataListRequest(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TCONTAINERDATALISTREQUEST

  # @@protoc_insertion_point(class_scope:rpc.TContainerDataListRequest)

class TContainerKillRequest(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TCONTAINERKILLREQUEST

  # @@protoc_insertion_point(class_scope:rpc.TContainerKillRequest)

class TVersionRequest(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TVERSIONREQUEST

  # @@protoc_insertion_point(class_scope:rpc.TVersionRequest)

class TConvertPathRequest(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TCONVERTPATHREQUEST

  # @@protoc_insertion_point(class_scope:rpc.TConvertPathRequest)

class TContainerGetRequest(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TCONTAINERGETREQUEST

  # @@protoc_insertion_point(class_scope:rpc.TContainerGetRequest)

class TContainerWaitRequest(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TCONTAINERWAITREQUEST

  # @@protoc_insertion_point(class_scope:rpc.TContainerWaitRequest)

class TContainerRequest(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TCONTAINERREQUEST

  # @@protoc_insertion_point(class_scope:rpc.TContainerRequest)

class TContainerListResponse(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TCONTAINERLISTRESPONSE

  # @@protoc_insertion_point(class_scope:rpc.TContainerListResponse)

class TContainerGetPropertyResponse(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TCONTAINERGETPROPERTYRESPONSE

  # @@protoc_insertion_point(class_scope:rpc.TContainerGetPropertyResponse)

class TContainerGetDataResponse(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TCONTAINERGETDATARESPONSE

  # @@protoc_insertion_point(class_scope:rpc.TContainerGetDataResponse)

class TContainerPropertyListResponse(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType

  class TContainerPropertyListEntry(_message.Message):
    __metaclass__ = _reflection.GeneratedProtocolMessageType
    DESCRIPTOR = _TCONTAINERPROPERTYLISTRESPONSE_TCONTAINERPROPERTYLISTENTRY

    # @@protoc_insertion_point(class_scope:rpc.TContainerPropertyListResponse.TContainerPropertyListEntry)
  DESCRIPTOR = _TCONTAINERPROPERTYLISTRESPONSE

  # @@protoc_insertion_point(class_scope:rpc.TContainerPropertyListResponse)

class TContainerDataListResponse(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType

  class TContainerDataListEntry(_message.Message):
    __metaclass__ = _reflection.GeneratedProtocolMessageType
    DESCRIPTOR = _TCONTAINERDATALISTRESPONSE_TCONTAINERDATALISTENTRY

    # @@protoc_insertion_point(class_scope:rpc.TContainerDataListResponse.TContainerDataListEntry)
  DESCRIPTOR = _TCONTAINERDATALISTRESPONSE

  # @@protoc_insertion_point(class_scope:rpc.TContainerDataListResponse)

class TVersionResponse(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TVERSIONRESPONSE

  # @@protoc_insertion_point(class_scope:rpc.TVersionResponse)

class TContainerGetResponse(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType

  class TContainerGetValueResponse(_message.Message):
    __metaclass__ = _reflection.GeneratedProtocolMessageType
    DESCRIPTOR = _TCONTAINERGETRESPONSE_TCONTAINERGETVALUERESPONSE

    # @@protoc_insertion_point(class_scope:rpc.TContainerGetResponse.TContainerGetValueResponse)

  class TContainerGetListResponse(_message.Message):
    __metaclass__ = _reflection.GeneratedProtocolMessageType
    DESCRIPTOR = _TCONTAINERGETRESPONSE_TCONTAINERGETLISTRESPONSE

    # @@protoc_insertion_point(class_scope:rpc.TContainerGetResponse.TContainerGetListResponse)
  DESCRIPTOR = _TCONTAINERGETRESPONSE

  # @@protoc_insertion_point(class_scope:rpc.TContainerGetResponse)

class TContainerWaitResponse(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TCONTAINERWAITRESPONSE

  # @@protoc_insertion_point(class_scope:rpc.TContainerWaitResponse)

class TConvertPathResponse(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TCONVERTPATHRESPONSE

  # @@protoc_insertion_point(class_scope:rpc.TConvertPathResponse)

class TContainerResponse(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TCONTAINERRESPONSE

  # @@protoc_insertion_point(class_scope:rpc.TContainerResponse)

class TVolumeProperty(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TVOLUMEPROPERTY

  # @@protoc_insertion_point(class_scope:rpc.TVolumeProperty)

class TVolumePropertyDescription(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TVOLUMEPROPERTYDESCRIPTION

  # @@protoc_insertion_point(class_scope:rpc.TVolumePropertyDescription)

class TVolumeDescription(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TVOLUMEDESCRIPTION

  # @@protoc_insertion_point(class_scope:rpc.TVolumeDescription)

class TVolumePropertyListRequest(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TVOLUMEPROPERTYLISTREQUEST

  # @@protoc_insertion_point(class_scope:rpc.TVolumePropertyListRequest)

class TVolumePropertyListResponse(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TVOLUMEPROPERTYLISTRESPONSE

  # @@protoc_insertion_point(class_scope:rpc.TVolumePropertyListResponse)

class TVolumeCreateRequest(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TVOLUMECREATEREQUEST

  # @@protoc_insertion_point(class_scope:rpc.TVolumeCreateRequest)

class TVolumeLinkRequest(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TVOLUMELINKREQUEST

  # @@protoc_insertion_point(class_scope:rpc.TVolumeLinkRequest)

class TVolumeUnlinkRequest(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TVOLUMEUNLINKREQUEST

  # @@protoc_insertion_point(class_scope:rpc.TVolumeUnlinkRequest)

class TVolumeListRequest(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TVOLUMELISTREQUEST

  # @@protoc_insertion_point(class_scope:rpc.TVolumeListRequest)

class TVolumeTuneRequest(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TVOLUMETUNEREQUEST

  # @@protoc_insertion_point(class_scope:rpc.TVolumeTuneRequest)

class TVolumeListResponse(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TVOLUMELISTRESPONSE

  # @@protoc_insertion_point(class_scope:rpc.TVolumeListResponse)

class TLayerImportRequest(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TLAYERIMPORTREQUEST

  # @@protoc_insertion_point(class_scope:rpc.TLayerImportRequest)

class TLayerExportRequest(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TLAYEREXPORTREQUEST

  # @@protoc_insertion_point(class_scope:rpc.TLayerExportRequest)

class TLayerRemoveRequest(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TLAYERREMOVEREQUEST

  # @@protoc_insertion_point(class_scope:rpc.TLayerRemoveRequest)

class TLayerListRequest(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TLAYERLISTREQUEST

  # @@protoc_insertion_point(class_scope:rpc.TLayerListRequest)

class TLayerListResponse(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TLAYERLISTRESPONSE

  # @@protoc_insertion_point(class_scope:rpc.TLayerListResponse)


# @@protoc_insertion_point(module_scope)



from setuptools import setup

def readme():
    with open('README.rst') as f:
        return f.read()

setup(name='portopy',
    version='2.11.1',
    description='Python API for porto',
    long_description=readme(),
    url='https://github.com/yandex/porto',
    author='marchael',
    author_email='marchael@yandex-team.ru',
    license='none',
    packages=['porto'],
    install_requires=[
        'protobuf',
    ],
    zip_safe=False)

